{ pkgs, lib, ... }:
with lib;
with lib.plusultra;
{
  imports = [ ./hardware-configuration.nix ];

  plusultra = {
    base.enable = true;
    gui.enable = true;
    nix-ld.enable = true;
    nix.enable = true;
    nix.extra-substituters."https://nixsgx.cachix.org".key = "nixsgx.cachix.org-1:tGi36DlY2joNsIXOlGnSgWW0+E094V6hW0umQRo/KoE=";
    podman.enable = true;
    secureboot.enable = false;
  };

  system.autoUpgrade = {
    enable = true;
    operation = "boot";
    allowReboot = false;
  };

  system.stateVersion = "23.11";

  sops.age.sshKeyPaths = [ "/persist/ssh/ssh_host_ed25519_key" ];
  sops.secrets.backup-s3.sopsFile = ../../../.secrets/t15/backup-s3.yaml;
  sops.secrets.backup-pw.sopsFile = ../../../.secrets/t15/backup-s3.yaml;

  services.openssh.hostKeys = [
    {
      path = "/persist/ssh/ssh_host_ed25519_key";
      type = "ed25519";
    }
    {
      path = "/persist/ssh/ssh_host_rsa_key";
      type = "rsa";
      bits = 4096;
    }
  ];

}
